/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl.db;

import com.topcoder.db.connectionfactory.DBConnectionFactory;

import com.topcoder.document.index.CollectionIndex;
import com.topcoder.document.index.DocumentIndex;
import com.topcoder.document.index.persistence.IndexPersistenceException;
import com.topcoder.document.index.persistence.impl.PersistenceConfigurationException;
import com.topcoder.document.index.wordsource.WordSourceId;

import java.util.Set;


/**
 * <p>
 * Extends the <code>AbstractDBIndexPersistence</code> abstract class for testing.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class MockAbstractDBIndexPersistence extends AbstractDBIndexPersistence {
    /**
     * <p>
     * Creates the new <code>MockAbstractDBIndexPersistence</code> class. A mock constructor here, simply calls the
     * super class's constructor.
     * </p>
     *
     * @param namespace the namespace to load the property values required by this class.
     *
     * @throws IllegalArgumentException if <code>namespace</code> is <code>null</code> or empty string.
     * @throws PersistenceConfigurationException if it fails to load the property values required by this class or some
     *         of the property values is invalid.
     */
    public MockAbstractDBIndexPersistence(String namespace) throws PersistenceConfigurationException {
        super(namespace);
    }

    /**
     * <p>
     * Creates the new <code>MockAbstractDBIndexPersistence</code> class. A mock constructor here, simply calls the
     * super class's constructor.
     * </p>
     *
     * @param connectionFactory the connection factory from which we can obtain a pre-configured connection for our
     *        data base access.
     * @param connectionName a connection name (an alias) that is used to fetch a connection instance from the
     *        connection factory.
     *
     * @throws IllegalArgumentException if <code>connectionFactory</code> is <code>null</code>
     */
    protected MockAbstractDBIndexPersistence(DBConnectionFactory connectionFactory, String connectionName) {
        super(connectionFactory, connectionName);
    }

    /**
     * <p>
     * Adds the given document index to the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param documentIndex the document index to be persisted.
     *
     * @throws IllegalArgumentException if <code>documentIndex</code> is <code>null</code>.
     * @throws IndexPersistenceException if persisting the document index fails; or the document index exists in the
     *         persistence.
     */
    public void addDocumentIndex(DocumentIndex documentIndex) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Gets the document index from the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param wordSourceId the ID of the document whose index is retrieved.
     *
     * @return the document index of the document with the ID.
     *
     * @throws IllegalArgumentException if <code>wordSourceId</code> is <code>null</code>.
     * @throws IndexPersistenceException if retrieving the document index fails.
     */
    public DocumentIndex getDocumentIndex(WordSourceId wordSourceId) throws IndexPersistenceException {
        return null;
    }

    /**
     * <p>
     * Removes a document index from the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param wordSourceId the ID of the document whose index is deleted.
     *
     * @throws IllegalArgumentException if <code>wordSourceId</code> is <code>null</code>.
     * @throws IndexPersistenceException if deleting the document index fails; or the document index is not persisted;
     *         or there is at least one collection containing the document index.
     */
    public void removeDocumentIndex(WordSourceId wordSourceId) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Adds the collection index to the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param collectionIndex the collection index to be persisted.
     *
     * @throws IllegalArgumentException if <code>collectionIndex</code> is <code>null</code>.
     * @throws IndexPersistenceException if persisting the collection index fails; or the collection index exists in
     *         the persistence.
     */
    public void addCollectionIndex(CollectionIndex collectionIndex) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Gets the collection index from the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param collectionId the ID of the collection index to be retrieved.
     *
     * @return the collection index with the given ID.
     *
     * @throws IllegalArgumentException if <code>collectionId</code> is <code>null</code> or empty string.
     * @throws IndexPersistenceException if retrieving the collection index fails.
     */
    public CollectionIndex getCollectionIndex(String collectionId) throws IndexPersistenceException {
        return null;
    }

    /**
     * <p>
     * Removes the collection index from the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param collectionId the ID of the collection index to be deleted.
     *
     * @throws IllegalArgumentException if <code>collectionId</code> is <code>null</code> or empty string.
     * @throws IndexPersistenceException if deleting the collection index fails; or the collection index ID cannot be
     *         found in the persistence.
     */
    public void removeCollectionIndex(String collectionId) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Updates the collection index in the persistence. A mock method, do nothing here.
     * </p>
     *
     * @param collectionIndex the collection index to be updated.
     *
     * @throws IllegalArgumentException if <code>collectionIndex</code> is <code>null</code>.
     * @throws IndexPersistenceException if updating the collection index fails; or the collection index ID cannot be
     *         found in the persistence.
     */
    public void updateCollectionIndex(CollectionIndex collectionIndex) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Increases the collection reference count of the document index. A mock method, do nothing here.
     * </p>
     *
     * @param wordSourceId the ID of the document whose collection reference count is increased by 1.
     *
     * @throws IllegalArgumentException if <code>wordSourceId</code> is <code>null</code>.
     * @throws IndexPersistenceException if increasing the collection reference count fails; or the document index is
     *         not persisted.
     */
    public void increaseDocumentUseCount(WordSourceId wordSourceId) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Decreases the collection reference count of the document index. A mock method, do nothing here.
     * </p>
     *
     * @param wordSourceId the ID of the document whose collection reference count is decreased by 1.
     *
     * @throws IllegalArgumentException if <code>wordSourceId</code> is <code>null</code>.
     * @throws IndexPersistenceException if decreasing the collection reference count fails; or the document index is
     *         not persisted; or the collection reference count is already 0.
     */
    public void decreaseDocumentUseCount(WordSourceId wordSourceId) throws IndexPersistenceException {
    }

    /**
     * <p>
     * Gets a set of all IDs of documents whose indices are persisted in the persistence. A mock method, do nothing
     * here.
     * </p>
     *
     * @return a set of all IDs of persisted document indices.
     *
     * @throws IndexPersistenceException if retrieving the document IDs fails.
     */
    public Set getIndexedDocuments() throws IndexPersistenceException {
        return null;
    }

    /**
     * <p>
     * Gets the reference count of the given document index. A mock method, do nothing here.
     * </p>
     *
     * @param wordSourceId the ID of the document index whose reference count is retrieved.
     *
     * @return the reference count of the document index.
     *
     * @throws IllegalArgumentException if <code>wordSourceId</code> is <code>null</code>.
     * @throws IndexPersistenceException if retrieving the collection reference count fails; or the document index is
     *         not persisted.
     */
    public int getDocumentUseCount(WordSourceId wordSourceId) throws IndexPersistenceException {
        return 0;
    }
}
